summaryrefslogtreecommitdiffstats
path: root/src/canvas
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 22:04:08 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 22:04:08 -0600
commite02e31c8b9d854cd62cbe9799228f6e08e882773 (patch)
tree53303c981d0b20e03c5a2fc8e959fa74adcb90d1 /src/canvas
parent143f194af098d44bf0dd1ebb29e59f30ce48d523 (diff)
downloadtqt3-e02e31c8b9d854cd62cbe9799228f6e08e882773.tar.gz
tqt3-e02e31c8b9d854cd62cbe9799228f6e08e882773.zip
Sync with latest script
Diffstat (limited to 'src/canvas')
-rw-r--r--src/canvas/qcanvas.cpp18
-rw-r--r--src/canvas/qcanvas.h2
2 files changed, 10 insertions, 10 deletions
diff --git a/src/canvas/qcanvas.h b/src/canvas/qcanvas.h
index 7cdd7a23..37c30816 100644
--- a/src/canvas/qcanvas.h
+++ b/src/canvas/qcanvas.h
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
diff --git a/src/canvas/qcanvas.cpp b/src/canvas/qcanvas.cpp
index 0cf7010d..167e0209 100644
--- a/src/canvas/qcanvas.cpp
+++ b/src/canvas/qcanvas.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
** Public Licensing retquirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -778,10 +778,10 @@ void TQCanvas::resize(int w, int h)
chunksze wide by \a chunksze high. Use a chunk size which is about
the average size of the canvas items. If you choose a chunk size
which is too small it will increase the amount of calculation
- retquired when drawing since each change will affect many chunks.
+ required when drawing since each change will affect many chunks.
If you choose a chunk size which is too large the amount of
- drawing retquired will increase because for each change, a lot of
- drawing will be retquired since there will be many (unchanged)
+ drawing required will increase because for each change, a lot of
+ drawing will be required since there will be many (unchanged)
canvas items which are in the same chunk as the changed canvas
items.
@@ -1025,7 +1025,7 @@ void TQCanvas::setUpdatePeriod(int ms)
canvas item is called with paramater 0. Then all these canvas
items are called again, with parameter 1. In phase 0, the canvas
items should not change position, merely examine other items on
- the canvas for which special processing is retquired, such as
+ the canvas for which special processing is required, such as
collisions between items. In phase 1, all canvas items should
change positions, ignoring any other items on the canvas. This
two-phase approach allows for considerations of "fairness",
@@ -3748,7 +3748,7 @@ TQSize TQCanvasView::sizeHint() const
Derived classes should try to define as small an area as possible
to maximize efficiency, but the polygon must \e definitely be
contained completely within the polygonal area. Calculating the
- exact retquirements is usually difficult, but if you allow a small
+ exact requirements is usually difficult, but if you allow a small
overestimate it can be easy and tquick, while still getting almost
all of TQCanvasPolygonalItem's speed.
@@ -4285,12 +4285,12 @@ TQCanvasSpline::~TQCanvasSpline()
If \a close is TRUE, then the first point in \a ctrl will be
re-used as the last point, and the number of control points must
be a multiple of 3. If \a close is FALSE, one additional control
- point is retquired, and the number of control points must be one of
+ point is required, and the number of control points must be one of
(4, 7, 10, 13, ...).
If the number of control points doesn't meet the above conditions,
the number of points will be truncated to the largest number of
- points that do meet the retquirement.
+ points that do meet the requirement.
*/
void TQCanvasSpline::setControlPoints(TQPointArray ctrl, bool close)
{
@@ -4388,7 +4388,7 @@ TQPointArray TQCanvasPolygon::areaPoints() const
// ### mark: Why don't we offer a constructor that lets the user set the
// points -- that way for some uses just the constructor call would be
-// retquired?
+// required?
/*!
\class TQCanvasLine qcanvas.h
\brief The TQCanvasLine class provides a line on a TQCanvas.
@@ -18,7 +18,7 @@
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please